@@ -1,5 +1,5 @@
 package cPanel::StateFile::FileLocker;
-$cPanel::StateFile::FileLocker::VERSION = '0.750';
+$cPanel::StateFile::FileLocker::VERSION = '0.800';
 # cpanel - cPanel/StateFile/FileLocker.pm         Copyright(c) 2014 cPanel, Inc.
 #                                                           All rights Reserved.
 # copyright@cpanel.net                                         http://cpanel.net
@@ -75,9 +75,6 @@ sub file_lock {
             return $lockfile;
         }
 
-        # Unable to create the lockfile.
-        $self->_info('Unable to create the lockfile, waiting');
-
         while ( $deadline > time ) {
             my ( $pid, $name, $max_time ) = $self->_read_lock_file($lockfile);
             unless ($pid) {
